IndexSchema class

This schema represents an index.

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → int
Internal id of this index.
final
name → String
Name of this index.
final
properties → List<IndexPropertySchema>
Composite properties.
final
replace → bool
Whether duplocates will be replaced or throw an error.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unique → bool
Whether duplicates are disallowed in this index.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited