ObjectFilter class

Filter condition based on an embedded object.

Constructors

ObjectFilter({required String property, required FilterOperation filter})
Create a filter condition based on an embedded object.
const

Properties

filter → FilterOperation
Filter condition that should be applied
final
hashCode → int
The hash code for this object.
no setterinherited
property → String
Property containing the embedded object(s).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited