PropertySchema class

A single propery of a collection or embedded object.

Properties

enumMap → Map<String, dynamic>?
Maps enum names to database values
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
Internal id of this property.
final
name → String
Name of the property
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
target → String?
For embedded objects: Name of the target schema
final
type → IsarType
Isar type of the property
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited