QueryExecute<OBJ, R> extension

Extension for QueryBuilders

on

Methods

build() → Query<R>

Available on QueryBuilder<OBJ, R, QQueryOperations>, provided by the QueryExecute extension

Create a query from this query builder.
count() → Future<int>

Available on QueryBuilder<OBJ, R, QQueryOperations>, provided by the QueryExecute extension

Count how many objects match this query.
countSync() → int

Available on QueryBuilder<OBJ, R, QQueryOperations>, provided by the QueryExecute extension

Count how many objects match this query.
deleteAll() → Future<int>

Available on QueryBuilder<OBJ, R, QQueryOperations>, provided by the QueryExecute extension

Delete all objects that match this query. Returns the number of deleted objects.
deleteAllSync() → int

Available on QueryBuilder<OBJ, R, QQueryOperations>, provided by the QueryExecute extension

Delete all objects that match this query. Returns the number of deleted objects.
deleteFirst() → Future<bool>

Available on QueryBuilder<OBJ, R, QQueryOperations>, provided by the QueryExecute extension

Delete the first object that matches this query. Returns whether a object has been deleted.
deleteFirstSync() → bool

Available on QueryBuilder<OBJ, R, QQueryOperations>, provided by the QueryExecute extension

Delete the first object that matches this query. Returns whether a object has been deleted.
exportJson() → Future<List<Map<String, dynamic>>>

Available on QueryBuilder<OBJ, R, QQueryOperations>, provided by the QueryExecute extension

Export the results of this query as json.
exportJsonRaw<T>(T callback(Uint8List)) → Future<R>

Available on QueryBuilder<OBJ, R, QQueryOperations>, provided by the QueryExecute extension

Export the results of this query as json bytes.
exportJsonRawSync<T>(T callback(Uint8List)) → T

Available on QueryBuilder<OBJ, R, QQueryOperations>, provided by the QueryExecute extension

Export the results of this query as json bytes.
exportJsonSync() → List<Map<String, dynamic>>

Available on QueryBuilder<OBJ, R, QQueryOperations>, provided by the QueryExecute extension

Export the results of this query as json.
findAll() → Future<List<R>>

Available on QueryBuilder<OBJ, R, QQueryOperations>, provided by the QueryExecute extension

Find all objects that match this query.
findAllSync() → List<R>

Available on QueryBuilder<OBJ, R, QQueryOperations>, provided by the QueryExecute extension

Find all objects that match this query.
findFirst() → Future<R?>

Available on QueryBuilder<OBJ, R, QQueryOperations>, provided by the QueryExecute extension

Find the first object that matches this query or null if no object matches.
findFirstSync() → R?

Available on QueryBuilder<OBJ, R, QQueryOperations>, provided by the QueryExecute extension

Find the first object that matches this query or null if no object matches.
isEmpty() → Future<bool>

Available on QueryBuilder<OBJ, R, QQueryOperations>, provided by the QueryExecute extension

Returns true if there are no objects that match this query.
isEmptySync() → bool

Available on QueryBuilder<OBJ, R, QQueryOperations>, provided by the QueryExecute extension

Returns true if there are no objects that match this query.
isNotEmpty() → Future<bool>

Available on QueryBuilder<OBJ, R, QQueryOperations>, provided by the QueryExecute extension

Returns true if there are objects that match this query.
isNotEmptySync() → bool

Available on QueryBuilder<OBJ, R, QQueryOperations>, provided by the QueryExecute extension

Returns true if there are objects that match this query.
watch({bool fireImmediately = false}) → Stream<List<R>>

Available on QueryBuilder<OBJ, R, QQueryOperations>, provided by the QueryExecute extension

Create a watcher that yields the results of this query whenever its results have (potentially) changed.
watchLazy({bool fireImmediately = false}) → Stream<void>

Available on QueryBuilder<OBJ, R, QQueryOperations>, provided by the QueryExecute extension

Watch the query for changes. If fireImmediately is true, an event will be fired immediately.