QueryExecuteAggregation<OBJ, T extends num> extension

Extension for QueryBuilders

on

Methods

average() → Future<double>

Available on QueryBuilder<OBJ, T?, QQueryOperations>, provided by the QueryExecuteAggregation extension

Returns the average value of this query.
averageSync() → double

Available on QueryBuilder<OBJ, T?, QQueryOperations>, provided by the QueryExecuteAggregation extension

Returns the average value of this query.
max() → Future<T?>

Available on QueryBuilder<OBJ, T?, QQueryOperations>, provided by the QueryExecuteAggregation extension

Returns the maximum value of this query.
maxSync() → T?

Available on QueryBuilder<OBJ, T?, QQueryOperations>, provided by the QueryExecuteAggregation extension

Returns the maximum value of this query.
min() → Future<T?>

Available on QueryBuilder<OBJ, T?, QQueryOperations>, provided by the QueryExecuteAggregation extension

Returns the minimum value of this query.
minSync() → T?

Available on QueryBuilder<OBJ, T?, QQueryOperations>, provided by the QueryExecuteAggregation extension

Returns the minimum value of this query.
sum() → Future<T>

Available on QueryBuilder<OBJ, T?, QQueryOperations>, provided by the QueryExecuteAggregation extension

Returns the sum of all values of this query.
sumSync() → T

Available on QueryBuilder<OBJ, T?, QQueryOperations>, provided by the QueryExecuteAggregation extension

Returns the sum of all values of this query.